@@ -14,12 +14,21 @@ from .aggregate import (
     AggregateDiff,
     AggregateRef,
 )
+from .entities import (
+    Entity,
+    EntitySet,
+    EntitySetDiff,
+    EntitySetDiffEntry,
+)
 from .networks import (
     Command,
     CommandReply,
     CommandStatus,
     Event,
 )
-from .value_object import (
+from .value_objects import (
     ValueObject,
+    ValueObjectSet,
+    ValueObjectSetDiff,
+    ValueObjectSetDiffEntry,
 )
