@@ -10,12 +10,16 @@ from __future__ import (
 )
 
 import logging
+from datetime import (
+    datetime,
+)
 from operator import (
     attrgetter,
 )
 from typing import (
     TYPE_CHECKING,
     Any,
+    Union,
 )
 from uuid import (
     UUID,
@@ -25,6 +29,7 @@ from ...actions import (
     Action,
 )
 from ...dynamic import (
+    FieldDiff,
     FieldDiffContainer,
 )
 from ..abc import (
@@ -32,6 +37,9 @@ from ..abc import (
 )
 
 if TYPE_CHECKING:
+    from ....repository import (
+        RepositoryEntry,
+    )
     from .model import (
         Aggregate,
     )
@@ -46,15 +54,47 @@ class AggregateDiff(DeclarativeModel):
     name: str
     version: int
     action: Action
+    created_at: datetime
+
     fields_diff: FieldDiffContainer
 
     def __getattr__(self, item: str) -> Any:
         try:
             return super().__getattr__(item)
         except AttributeError as exc:
-            if item != "fields_diff":
-                return getattr(self.fields_diff, item).value
-            raise exc
+            try:
+                return self.get_one(item)
+            except Exception:
+                raise exc
+
+    def get_one(self, name: str, return_diff: bool = False) -> Union[FieldDiff, Any, list[FieldDiff], list[Any]]:
+        """Get first field diff with given name.
+
+        :param name: The name of the field diff.
+        :param return_diff: If ``True`` the result is returned as field diff instances, otherwise the result is
+            returned as value instances.
+        :return: A ``FieldDiff`` instance.
+        """
+        return self.fields_diff.get_one(name, return_diff)
+
+    def get_all(self, return_diff: bool = False) -> dict[str, Union[FieldDiff, Any, list[FieldDiff], list[Any]]]:
+        """Get all field diffs with given name.
+
+        :param return_diff: If ``True`` the result is returned as field diff instances, otherwise the result is
+            returned as value instances.
+        :return: A list of ``FieldDiff`` instances.
+        """
+        return self.fields_diff.get_all(return_diff)
+
+    def update_from_repository_entry(self, entry: RepositoryEntry) -> None:
+        """Update metadata from a repository entry.
+
+        :param entry: A repository entry.
+        :return: This method does not return anything.
+        """
+        self.uuid = entry.aggregate_uuid
+        self.version = entry.version
+        self.created_at = entry.created_at
 
     @classmethod
     def from_difference(cls, a: Aggregate, b: Aggregate, action: Action = Action.UPDATE) -> AggregateDiff:
@@ -75,9 +115,16 @@ class AggregateDiff(DeclarativeModel):
 
         old, new = sorted([a, b], key=attrgetter("version"))
 
-        fields_diff = FieldDiffContainer.from_difference(a, b, ignore={"uuid", "version"})
+        fields_diff = FieldDiffContainer.from_difference(a, b, ignore={"uuid", "version", "created_at", "updated_at"})
 
-        return cls(new.uuid, new.classname, new.version, action, fields_diff)
+        return cls(
+            uuid=new.uuid,
+            name=new.classname,
+            version=new.version,
+            action=action,
+            created_at=new.updated_at,
+            fields_diff=fields_diff,
+        )
 
     @classmethod
     def from_aggregate(cls, aggregate: Aggregate, action: Action = Action.CREATE) -> AggregateDiff:
@@ -88,8 +135,15 @@ class AggregateDiff(DeclarativeModel):
         :return: An ``AggregateDiff`` instance.
         """
 
-        fields_diff = FieldDiffContainer.from_model(aggregate, ignore={"uuid", "version"})
-        return cls(aggregate.uuid, aggregate.classname, aggregate.version, action, fields_diff)
+        fields_diff = FieldDiffContainer.from_model(aggregate, ignore={"uuid", "version", "created_at", "updated_at"})
+        return cls(
+            uuid=aggregate.uuid,
+            name=aggregate.classname,
+            version=aggregate.version,
+            action=action,
+            created_at=aggregate.updated_at,
+            fields_diff=fields_diff,
+        )
 
     @classmethod
     def from_deleted_aggregate(cls, aggregate: Aggregate, action: Action = Action.DELETE) -> AggregateDiff:
@@ -99,7 +153,14 @@ class AggregateDiff(DeclarativeModel):
         :param action: The action to that generates the aggregate difference.
         :return: An ``AggregateDiff`` instance.
         """
-        return cls(aggregate.uuid, aggregate.classname, aggregate.version, action, FieldDiffContainer.empty())
+        return cls(
+            uuid=aggregate.uuid,
+            name=aggregate.classname,
+            version=aggregate.version,
+            action=action,
+            created_at=aggregate.updated_at,
+            fields_diff=FieldDiffContainer.empty(),
+        )
 
     def decompose(self) -> list[AggregateDiff]:
         """Decompose AggregateDiff Fields into AggregateDiff with once Field.
@@ -107,6 +168,13 @@ class AggregateDiff(DeclarativeModel):
         :return: An list of``AggregateDiff`` instances.
         """
         return [
-            AggregateDiff(self.uuid, self.name, self.version, self.action, FieldDiffContainer([diff]))
-            for diff in self.fields_diff.values()
+            type(self)(
+                uuid=self.uuid,
+                name=self.name,
+                version=self.version,
+                action=self.action,
+                created_at=self.created_at,
+                fields_diff=FieldDiffContainer([diff]),
+            )
+            for diff in self.fields_diff.flatten_values()
         ]
