@@ -13,15 +13,17 @@ from .comparators import (
     TypeHintComparator,
     is_aggregate_type,
     is_model_subclass,
+    is_model_type,
     is_type_subclass,
 )
-from .data_types import (
-    Decimal,
-    Enum,
-    Fixed,
+from .constants import (
     MissingSentinel,
     NoneType,
 )
+from .generics import (
+    GenericTypeProjector,
+    unpack_typevar,
+)
 from .model_refs import (
     ModelRef,
     ModelRefExtractor,
