@@ -12,11 +12,8 @@ from __future__ import (
 import logging
 from typing import (
     Any,
-    Generic,
     Iterable,
     Optional,
-    Type,
-    TypeVar,
     Union,
     get_args,
     get_origin,
@@ -27,18 +24,20 @@ from uuid import (
 
 from .comparators import (
     is_aggregate_type,
+    is_model_type,
     is_type_subclass,
 )
 from .model_refs import (
     ModelRef,
 )
+from .model_types import (
+    ModelType,
+)
 
 logger = logging.getLogger(__name__)
 
-T = TypeVar("T")
 
-
-def build_union(options: tuple[Type[T], ...]) -> Type[T]:
+def build_union(options: tuple[type, ...]) -> type:
     """Build the union type base on the given options.
 
     :param options: A tuple of types.
@@ -55,52 +54,52 @@ def build_union(options: tuple[Type[T], ...]) -> Type[T]:
     return Union[options]
 
 
-class TypeHintBuilder(Generic[T]):
+class TypeHintBuilder:
     """Type Hint Builder class."""
 
-    def __init__(self, value: T, base: Optional[Type[T]] = None):
-        self._value = value
-        self._base = base
+    def __init__(self, value: Any, type_: Optional[type] = None):
+        self.value = value
+        self.type_ = type_
 
-    def build(self) -> Type[T]:
+    def build(self) -> type:
         """Build type hint from an instance..
 
         :return: A type.
         """
-        return self._build(self._value, self._base)
+        return self._build(self.value, self.type_)
 
-    def _build(self, value: T, base: Optional[Type[T]]) -> Type[T]:
-        if base is not None:
-            if get_origin(base) is ModelRef:
-                base = Union[(*get_args(base), UUID)]
+    def _build(self, value, type_: Optional[type]) -> type:
+        if type_ is not None:
+            if get_origin(type_) is ModelRef:
+                type_ = Union[(*get_args(type_), UUID)]
 
-            if get_origin(base) is Union:
-                dynamic: Type[T] = self._build(value, None)
+            if get_origin(type_) is Union:
+                dynamic = self._build(value, None)
                 options = tuple(
                     (dynamic if not len(get_args(static)) and issubclass(dynamic, static) else static)
-                    for static in get_args(base)
+                    for static in get_args(type_)
                 )
                 return build_union(options)
 
         if isinstance(value, (tuple, list, set)):
-            b1 = Any if (base is None or len(get_args(base)) != 1) else get_args(base)[0]
+            b1 = Any if (type_ is None or len(get_args(type_)) != 1) else get_args(type_)[0]
             return type(value)[self._build_from_iterable(value, b1)]
 
         if isinstance(value, dict):
-            b1, b2 = (Any, Any) if (base is None or len(get_args(base)) != 2) else get_args(base)
+            b1, b2 = (Any, Any) if (type_ is None or len(get_args(type_)) != 2) else get_args(type_)
             return type(value)[
                 self._build_from_iterable(value.keys(), b1), self._build_from_iterable(value.values(), b2)
             ]
 
-        if hasattr(value, "model_type"):
-            return value.model_type
+        if is_model_type(value):
+            return ModelType.from_model(value)
 
         return type(value)
 
-    def _build_from_iterable(self, values: Iterable[T], base: Optional[Type[T]]) -> Type[T]:
+    def _build_from_iterable(self, values: Iterable, type_: Optional[type]) -> type:
         values = tuple(values)
         if len(values) == 0:
-            return base
+            return type_
 
-        options = tuple(self._build(value, base) for value in values)
+        options = tuple(self._build(value, type_) for value in values)
         return build_union(options)
